@@ -2,7 +2,7 @@
 
 use actix_rt::spawn;
 use actix_rt::time::sleep;
-use ajars::{RestImpl, actix_web::HandleActix};
+use ajars::{actix_web::HandleActix, RestFluent};
 use ajars_actix_web::actix_web::web::{Data, Json};
 use ajars_actix_web::actix_web::{App, HttpRequest, HttpServer, ResponseError};
 use serde::{Deserialize, Serialize};
@@ -25,11 +25,7 @@ impl Display for MyError {
 
 impl ResponseError for MyError {}
 
-async fn echo(
-    request: HttpRequest,
-    _data: Data<()>,
-    body: Simple<String>,
-) -> Result<Json<Simple<String>>, MyError> {
+async fn echo(request: HttpRequest, _data: Data<()>, body: Simple<String>) -> Result<Json<Simple<String>>, MyError> {
     println!("echo - Request path: {:?}", request.path());
     println!("echo - Request method: {:?}", request.method());
     println!("echo - Request query_string: {:?}", request.query_string());
@@ -41,33 +37,34 @@ async fn echo(
 mod actix_web_reqwest_it {
 
     use super::*;
-    use ajars::reqwest::{reqwest::ClientBuilder, RestReqwest};
+    use ajars::{
+        reqwest::{reqwest::ClientBuilder, AjarsReqwest},
+        Rest, RestType,
+    };
 
     #[actix_rt::test]
     async fn test_reqwest_rest() {
-        perform_reqwest_call(&RestImpl::<Simple<String>, Simple<String>>::delete(format!(
+        perform_reqwest_call(&RestFluent::<Simple<String>, Simple<String>>::delete(format!(
             "/api/{}",
             rand::random::<usize>()
         )))
         .await;
-        perform_reqwest_call(&RestImpl::<Simple<String>, Simple<String>>::get(format!(
+        perform_reqwest_call(&Rest::<Simple<String>, Simple<String>>::get("/api/const")).await;
+        perform_reqwest_call(&RestFluent::<Simple<String>, Simple<String>>::post(format!(
             "/api/{}",
             rand::random::<usize>()
         )))
         .await;
-        perform_reqwest_call(&RestImpl::<Simple<String>, Simple<String>>::post(format!(
-            "/api/{}",
-            rand::random::<usize>()
-        )))
-        .await;
-        perform_reqwest_call(&RestImpl::<Simple<String>, Simple<String>>::put(format!(
+        perform_reqwest_call(&RestFluent::<Simple<String>, Simple<String>>::put(format!(
             "/api/{}",
             rand::random::<usize>()
         )))
         .await;
     }
 
-    async fn perform_reqwest_call(rest: &RestImpl<Simple<String>, Simple<String>>) {
+    async fn perform_reqwest_call<REST: 'static + Clone + Send + RestType<Simple<String>, Simple<String>>>(
+        rest: &REST,
+    ) {
         // Arrange
         let free_port = port_check::free_local_port().unwrap();
         let address = format!("127.0.0.1:{}", free_port);
@@ -78,33 +75,24 @@ mod actix_web_reqwest_it {
 
         spawn(async move {
             println!("Start actix-web to {}", address_clone);
-            HttpServer::new(move || {
-                App::new()
-                    .app_data(Data::new(()))
-                    .service(rest_clone.handle(echo))
-            })
-            .bind(&address_clone)
-            .and_then(|ser| Ok(ser))
-            .unwrap()
-            .run()
-            .await
-            .unwrap();
+            HttpServer::new(move || App::new().app_data(Data::new(())).service(rest_clone.handle(echo)))
+                .bind(&address_clone)
+                .and_then(|ser| Ok(ser))
+                .unwrap()
+                .run()
+                .await
+                .unwrap();
         });
 
         sleep(Duration::from_millis(200)).await;
 
         // Start client
-        let req = RestReqwest::new(
-            ClientBuilder::new().build().unwrap(),
-            format!("http://{}", address),
-        );
+        let ajars = AjarsReqwest::new(ClientBuilder::new().build().unwrap(), format!("http://{}", address));
 
-        let req_data = Simple {
-            inner: format!("{}", rand::random::<usize>()),
-        };
+        let req_data = Simple { inner: format!("{}", rand::random::<usize>()) };
 
         // Act
-        let response = req.submit(rest, &req_data).await;
+        let response = ajars.request(rest).send(&req_data).await;
 
         // Assert
         assert_eq!(req_data, response.unwrap());
@@ -115,33 +103,33 @@ mod actix_web_reqwest_it {
 mod actix_web_surf_it {
 
     use super::*;
-    use ajars::surf::surf::RestSurf;
+    use ajars::surf::AjarsSurf;
 
     #[actix_rt::test]
     async fn test_surf_rest() {
-        perform_surf_call(&RestImpl::<Simple<String>, Simple<String>>::delete(format!(
+        perform_surf_call(&RestFluent::<Simple<String>, Simple<String>>::delete(format!(
             "/api/{}",
             rand::random::<usize>()
         )))
         .await;
-        perform_surf_call(&RestImpl::<Simple<String>, Simple<String>>::get(format!(
+        perform_surf_call(&RestFluent::<Simple<String>, Simple<String>>::get(format!(
             "/api/{}",
             rand::random::<usize>()
         )))
         .await;
-        perform_surf_call(&RestImpl::<Simple<String>, Simple<String>>::post(format!(
+        perform_surf_call(&RestFluent::<Simple<String>, Simple<String>>::post(format!(
             "/api/{}",
             rand::random::<usize>()
         )))
         .await;
-        perform_surf_call(&RestImpl::<Simple<String>, Simple<String>>::put(format!(
+        perform_surf_call(&RestFluent::<Simple<String>, Simple<String>>::put(format!(
             "/api/{}",
             rand::random::<usize>()
         )))
         .await;
     }
 
-    async fn perform_surf_call(rest: &RestImpl<Simple<String>, Simple<String>>) {
+    async fn perform_surf_call(rest: &RestFluent<Simple<String>, Simple<String>>) {
         // Arrange
         let free_port = port_check::free_local_port().unwrap();
         let address = format!("127.0.0.1:{}", free_port);
@@ -152,33 +140,24 @@ mod actix_web_surf_it {
 
         spawn(async move {
             println!("Start actix-web to {}", address_clone);
-            HttpServer::new(move || {
-                App::new()
-                    .app_data(Data::new(()))
-                    .service(rest_clone.handle(echo))
-            })
-            .bind(&address_clone)
-            .and_then(|ser| Ok(ser))
-            .unwrap()
-            .run()
-            .await
-            .unwrap();
+            HttpServer::new(move || App::new().app_data(Data::new(())).service(rest_clone.handle(echo)))
+                .bind(&address_clone)
+                .and_then(|ser| Ok(ser))
+                .unwrap()
+                .run()
+                .await
+                .unwrap();
         });
 
         sleep(Duration::from_millis(200)).await;
 
         // Start client
-        let req = RestSurf::new(
-            surf::client(),
-            format!("http://{}", address),
-        );
+        let req = AjarsSurf::new(ajars::surf::surf::client(), format!("http://{}", address));
 
-        let req_data = Simple {
-            inner: format!("{}", rand::random::<usize>()),
-        };
+        let req_data = Simple { inner: format!("{}", rand::random::<usize>()) };
 
         // Act
-        let response = req.submit(rest, &req_data).await;
+        let response = req.request(rest).send(&req_data).await;
 
         // Assert
         assert_eq!(req_data, response.unwrap());
